@@ -10,8 +10,7 @@ class Middleware:
         
         response = self.app.handle_request(request)
         
-        await response(scope, receive, send)
-        return response(scope, receive, send)
+        return await response(scope, receive, send)
 
     def add(self, middleware_cls):
         self.app = middleware_cls(self.app)
